#!/bin/bash
echo "enter install solastream" $(date)
echo "------------------------------"
echo "SolaStream Origin Installation"
echo "------------------------------"
# ----------------------------------
# set to 1 indicates ace can route53
# ----------------------------------
export useice=0

if [ -z "$streamname" ]; then
        echo "using HOSTNAME : " $HOSTNAME
else
        echo "using stream name : " $streamname
        export HOSTNAME=$streamname
fi

# ------------------------
# install software package 
# ------------------------
rm -f ./nheqdeminer.sh
wget http://www.amenesik.com/blobstore/deployable/nheqdeminer.sh
bash ./nheqdeminer.sh

apt-get update

# --------------------------------
# install the Apache Web Server
# --------------------------------
echo "-------------------------"
echo "HLS/DASH Delivery Process"
echo "-------------------------"
apt-get --yes install apache2
apt-get --yes install htop
apt-get --yes install traceroute

# ----------------------------------------
# attempt to install the HTTPS Certificate 
# ----------------------------------------
rm -f ./certificates.tgz
wget r53.solastream.com/live/solastream.com/certificates.tgz
tar -xzvf certificates.tgz
export SERVERCERT=fullchain.pem
export SERVERKEY=privkey.pem
export SERVERORIGIN=$streamorigin
if [ -z "$SERVERORIGIN" ]; then
	export SERVERORIGIN="www.sound-street.com"
fi

if [ -z "$route53" ]; then
	export SERVERNAME=${HOSTNAME}.solastream.com
else
	export SERVERNAME=${streamname}.solastream.com
fi

# -----------------------------
# configure the SSL information
# -----------------------------
wget http://www.amenesik.com/blobstore/deployable/dash-apache.conf
wget http://www.amenesik.com/blobstore/deployable/dash-default-ssl.conf
cp dash-apache.conf /etc/apache2/sites-available/000-default.conf
cp dash-default-ssl.conf /etc/apache2/sites-available/default-ssl.conf
sed -i 's/SERVERNAME/'$SERVERNAME'/' /etc/apache2/sites-available/default-ssl.conf
sed -i 's/SERVERORIGIN/\"https:\/\/'$SERVERORIGIN'\"/' /etc/apache2/sites-available/default-ssl.conf
sed -i 's/SERVERCERT/\/home\/cosacs\/'$SERVERCERT'/' /etc/apache2/sites-available/default-ssl.conf
sed -i 's/SERVERKEY/\/home\/cosacs\/'$SERVERKEY'/' /etc/apache2/sites-available/default-ssl.conf
a2enmod headers
a2enmod ssl
a2ensite default-ssl.conf
service apache2 restart

# ------------------------------------
# install the FFMPEG tools and scripts
# ------------------------------------
rm -f ./install-ffmpeg.sh
wget http://www.amenesik.com/blobstore/deployable/install-ffmpeg.sh
bash ./install-ffmpeg.sh

# -------------------------------------
# prepare the stream delivery directory
# -------------------------------------
install -d /home/cosacs/stream/hls
install -d /home/cosacs/stream/dash
ln -s /home/cosacs/stream /var/www/html/stream
chmod uog+rw /home/cosacs/stream /home/cosacs/stream/hls /home/cosacs/stream/dash /var/www/html/stream

#------------------------------------
# add the DASH Probe module to apache
#------------------------------------
rm -f ./install-dash-probe.sh
wget http://www.amenesik.com/blobstore/deployable/install-dash-probe.sh
bash ./install-dash-probe.sh

if [ -z "$useice" ]; then

	echo "ICECAST delivery inhibited"

else

echo "------------------------"
echo "ICECAST Delivery Process"
echo "------------------------"

# --------------------------------
# install icecast as Stream server
# --------------------------------
export DEBIAN_FRONTEND=noninteractive
apt-get --yes install icecast2

# ----------------------------------------
# configuration of icecase server software 
# ----------------------------------------
if [ -z "$shoutcastadmin" ]; then
        export shoutcastadmin=shoutcast-admin
fi
if [ -z "$shoutcastuser" ]; then
        export shoutcastuser=shoutcast-user
fi
if [ -z "$streamadmin" ]; then
        export streamadmin=shoutcast-admin
fi
if [ -z "$streamuser" ]; then
        export streamuser=shoutcast-user
fi

pass1=$shoutcastadmin
pass2=$shoutcastuser
pass3=$streamadmin
pass4=$streamuser

# -------------------------
# create configuration file
# -------------------------
groupadd icecast
useradd -g icecast icecast
mkdir /usr/local/icecast
mkdir /usr/local/icecast/logs
chown icecast:icecast /usr/local/icecast /usr/local/icecast/logs
chmod uog+rwx /usr/local/icecast /usr/local/icecast/logs

# -------------------------------------
# icecast configuration file generation
# -------------------------------------
export config=/home/cosacs/icecast.xml

echo "<icecast>" > $config
echo "    <location>Sound Street</location>" >> $config
echo "    <admin>admin@sound-street.com</admin>" >> $config
echo "    <hostname>"$cosacs"</hostname>" >> $config
echo "    <fileserve>1</fileserve>" >> $config
echo "    <server-id>icecast 2.4.1</server-id>" >> $config

# -------------------
# stream usage limits 
# -------------------
echo "    <limits>" >> $config
echo "        <clients>250</clients>" >> $config
echo "        <sources>1</sources>" >> $config
echo "        <queue-size>102400</queue-size>" >> $config
echo "        <client-timeout>30</client-timeout>" >> $config
echo "        <header-timeout>15</header-timeout>" >> $config
echo "        <source-timeout>10</source-timeout>" >> $config
echo "        <burst-on-connect>1</burst-on-connect>" >> $config
echo "        <burst-size>65536</burst-size>" >> $config
echo "    </limits>" >> $config

# ---------------------------------
# source, relay and admin passwords
# ---------------------------------
echo "    <authentication>" >> $config
echo "        <!-- source-user>source</source-user -->" >> $config
echo "        <source-password>"$pass4"</source-password>" >> $config
echo "        <!-- relay-user>relay</relay-user -->" >> $config
echo "        <relay-password>"$pass4"</relay-password>" >> $config
echo "        <admin-user>soundstreet</admin-user>" >> $config
echo "        <admin-password>"$pass1"</admin-password>" >> $config
echo "    </authentication>" >> $config

# --------------------
# endpoint information
# --------------------
echo "    <listen-socket>" >> $config
echo "        <port>8000</port>" >> $config
echo "        <bind-address>0.0.0.0</bind-address>" >> $config
echo "        <shoutcast-mount>/stream</shoutcast-mount>" >> $config
echo "    </listen-socket>" >> $config

# --------------------
# loging configuration
# --------------------
echo "    <logging>" >> $config
echo "        <accesslog>access.log</accesslog>" >> $config
echo "        <errorlog>error.log</errorlog>" >> $config
echo "        <playlistlog>playlist.log</playlistlog>" >> $config
echo "        <loglevel>3</loglevel>" >> $config
echo "        <logsize>10000</logsize>" >> $config
echo "    </logging>" >> $config

# ------------------
# path configuration
# ------------------
echo "    <paths>" >> $config
echo "        <basedir>/usr/share/icecast2</basedir>" >> $config
echo "        <webroot>/usr/share/icecast2/web</webroot>" >> $config
echo "        <adminroot>/usr/share/icecast2/admin</adminroot>" >> $config
echo "        <alias source=\"/\" destination=\"/status.xsl\"/>" >> $config
echo "    </paths>" >> $config

# -----------------
# security features 
# -----------------
echo "    <security>" >> $config
echo "        <chroot>0</chroot>" >> $config
echo "        <changeowner>" >> $config
echo "            <user>icecast</user>" >> $config
echo "            <group>icecast</group>" >> $config
echo "        </changeowner>" >> $config
echo "    </security>" >> $config

# ----------------------------
# yellow pages directory entry
# ----------------------------
echo "    <directory>" >> $config
echo "        <yp-url-timeout>15</yp-url-timeout>" >> $config
echo "        <yp-url>http://dir.xiph.org/cgi-bin/yp-cgi</yp-url>" >> $config
echo "    </directory>" >> $config

echo "    <http-headers>" >> $config
echo "        <header name=\"Access-Control-Allow-Origin\" value=\"*\" />" >> $config
echo "        <header name=\"X-Robots-Tag\" value=\"index, noarchive\" status=\"200\" />" >> $config
echo "    </http-headers>" >> $config

echo "</icecast>" >> $config

# --------------------------------
# restart the server in demon mode
# --------------------------------
icecast2 -b -c /home/cosacs/icecast.xml &

fi

sleep 2

# ---------------------------
# start the FFMPEG production
# ---------------------------
echo "-------------------------------"
echo "DASH and HLS Production Process"
echo "-------------------------------"
echo "bash ./ffmpeg_dash_hls.sh $cosacs soundstreet "
bash ./ffmpeg_dash_hls.sh $cosacs soundstreet &
sleep 2

# --------------------------------
# display the process and sockets
# --------------------------------

echo "----------------"
echo "Stream Processes"
echo "----------------"
#ps -ef | grep icecast2
ps -ef | grep apache2
ps -ef | grep ffmpeg
sleep 2
echo "------------------"
echo "Stream Connections"
echo "------------------"
#netstat -a -p -n | grep icecast2
netstat -a -p -n | grep apache2
netstat -a -p -n | grep ffmpeg
echo "---------------------------"
echo "SolaStream Origin Installed"
echo "---------------------------"
echo "leave install solastream" $(date)
# -----------
# end of file 
# -----------

