#!/bin/bash
# ------------------------------------
# Generate HA Proxy Configuration File
# ------------------------------------
export HAPROXYCFG=/etc/haproxy/haproxy.cfg
echo "global "                                                  >  $HAPROXYCFG
echo "        maxconn 4096 "                                    >> $HAPROXYCFG
echo "        log 127.0.0.1 local5 debug  "                     >> $HAPROXYCFG
echo "        tune.ssl.default-dh-param 2048 "                  >> $HAPROXYCFG
echo "        ssl-default-bind-options no-sslv3 no-tls-tickets" >> $HAPROXYCFG
echo "        ssl-default-bind-ciphers ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:AES:CAMELLIA:DES-CBC3-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!aECDH:!EDH-DSS-DES-CBC3-SHA:!EDH-RSA-DES-CBC3-SHA:!KRB5-DES-CBC3-SHA " >> $HAPROXYCFG
echo "        ssl-default-server-options no-sslv3 no-tls-tickets " >> $HAPROXYCFG
echo "        ssl-default-server-ciphers ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:AES128-GCM-SHA256:AES256-GCM-SHA384:AES128-SHA256:AES256-SHA256:AES128-SHA:AES256-SHA:AES:CAMELLIA:DES-CBC3-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!MD5:!PSK:!aECDH:!EDH-DSS-DES-CBC3-SHA:!EDH-RSA-DES-CBC3-SHA:!KRB5-DES-CBC3-SHA " >> $HAPROXYCFG
echo "        log /dev/log    local0 "                          >> $HAPROXYCFG
echo "        log /dev/log    local1 notice "                   >> $HAPROXYCFG
echo "        chroot /var/lib/haproxy "                         >> $HAPROXYCFG
echo "        user haproxy "                                    >> $HAPROXYCFG
echo "        group haproxy "                                   >> $HAPROXYCFG
echo "        daemon "                                          >> $HAPROXYCFG
echo "defaults "                                                >> $HAPROXYCFG
echo "        log     global "                                  >> $HAPROXYCFG
echo "        option forwardfor "                               >> $HAPROXYCFG
echo "        option http-server-close "                        >> $HAPROXYCFG
echo "        mode    http "                                    >> $HAPROXYCFG
echo "        stats enable "                                    >> $HAPROXYCFG
echo "        stats uri /haproxy-stats "                        >> $HAPROXYCFG
echo "        stats enable admin:solastreamer"                  >> $HAPROXYCFG
echo "        option  httplog "                                 >> $HAPROXYCFG
echo "        option  dontlognull "                             >> $HAPROXYCFG
echo "        timeout connect 5000 "                            >> $HAPROXYCFG
echo "        timeout client  50000 "                           >> $HAPROXYCFG
echo "        timeout server  300000 "                          >> $HAPROXYCFG
echo "        errorfile 400 /etc/haproxy/errors/400.http "      >> $HAPROXYCFG
echo "        errorfile 403 /etc/haproxy/errors/403.http "      >> $HAPROXYCFG
echo "        errorfile 408 /etc/haproxy/errors/408.http "      >> $HAPROXYCFG
echo "        errorfile 500 /etc/haproxy/errors/500.http "      >> $HAPROXYCFG
echo "        errorfile 502 /etc/haproxy/errors/502.http "      >> $HAPROXYCFG
echo "        errorfile 503 /etc/haproxy/errors/503.http "      >> $HAPROXYCFG
echo "        errorfile 504 /etc/haproxy/errors/504.http "      >> $HAPROXYCFG
echo "frontend www-http "                                       >> $HAPROXYCFG
echo "        reqadd X-Forwarded-Proto:\ http "                 >> $HAPROXYCFG
echo "        redirect scheme https code 301 if !{ ssl_fc } "   >> $HAPROXYCFG
echo "        bind  " 0.0.0.0:80                                >> $HAPROXYCFG
echo "        default_backend www-backend "                     >> $HAPROXYCFG
echo "frontend www-https "                                      >> $HAPROXYCFG
echo "        bind  " 0.0.0.0:443 " ssl crt /home/cosacs/security/haproxy.pem no-sslv3 " >> $HAPROXYCFG
echo "        reqadd X-Forwarded-Proto:\ https "                >> $HAPROXYCFG
echo "        default_backend www-backend "                     >> $HAPROXYCFG
echo "backend www-backend "                                     >> $HAPROXYCFG
echo "        redirect scheme https code 301 if !{ ssl_fc } "   >> $HAPROXYCFG
echo "        balance roundrobin "                              >> $HAPROXYCFG

